@@ -158,7 +158,7 @@ class NetComp(object):
         pass
 
 
-    def all(self,component='',param=''):
+    def all(self,component='',param='',dict_entry=''):
         """Method of displaying of all attributes from the NetComp class instance.
         """
 
@@ -182,14 +182,11 @@ class NetComp(object):
         print("{0:30s} {1:>6s}".format('Length of PipeLines    [km]', str(round(self.sumLength('PipeLines')))))
         print("{0:30s} {1:>6s}".format('Length of PipeSegments [km]', str(round(self.sumLength('PipeSegments')))))
         if (component and param) !='':
-            param_list=[]
             for element in self.__dict__[component]:
-                print(element.__dict__[param])
-                param_list.append(element.__dict__[param])
-            
-            return param_list
-        else:
-            pass
+                if dict_entry=='':
+                    print(element.__dict__[param])
+                else:
+                    print(element.__dict__[param].get(dict_entry))
 
 
     def sumLength(self, compName = 'PipeLines'):
